#!/usr/bin/perl
use warnings;

our $source = 'AcmeMenu_source.js';
our $dest   = 'AcmeMenu.js';

=head1 NAME

stripmenu.pl - Strip comments and blank spaces from menu source code.

=head1 SYNOPSIS

    stripmenu.pl AcmeMenu_source.js AcmeMenu.js

=head1 DESCRIPTION

This program strips JavaScript source code of all its comments and debug statements.

All debug() function calls are remvoved from the code, and everything from 
"function debug(...) {" to the end of the file is removed.

Some of the initial patterns removed are dependent upon my coding style.

=head1 AUTHOR

Mack Pexton <mack@acmebase.org>

=head1 COPYRIGHT

Copyright 2003, Mackley F. Pexton.  All rights reserved.

This is open software and is licensed under the terms of the GNU General Public License.

=cut

if (-t && -f $dest) {
	print qq[The file "$dest" already exists. Overwrite it? (y/n) ];
	$_ = <STDIN>;
	/^y/i or die "File not written.\n"
}

open(IN, '<', $source) or die "Cannot open file $source. $!";
open(OUT,">$dest")     or die "Cannot open file $dest. $!";

local $/;	# read entire files

# Define regular expression to match matching parentheses (even if nested).
# From the Camel book, 3rd edition, p214.

our $matched_paren = qr{
			  \(
			  (?:
			    (?> [^()]+ )
			  |
			    (??{ $matched_paren })
			  )*
			  \)
			}x;

while (<IN>) {
	s|/\*\*.*?\*\*/||gs;		# strip big comments /** ... **/
	s|/\*\s*-*\s*\*/||gs;		# strip section dividers /* --- */

	s|/\*[\s*]+Debug.*\*/.*||s;	# delete debug function to EOF
	s|debug$matched_paren;?||g;	# remove debug statements
	s|if\s*\(\s*debug.is_on.*$||gm;	# remove special debug (Safari tests)

	s|\s*(?<!:)//.*$||gm;		# remove // comments (keep http://...)

	s|^\n\n*||;			# strip beginning blank lines

	print OUT $_;
}
